@@ -1,6 +1,4 @@
-"""constants.py
----------------
-
+"""
 This import hook makes it possible to define constants, that is variables
 which cannot have their initial value changed.
 
@@ -10,8 +8,6 @@ In this import hook, constants are identified in two ways:
 
 2. variables that were declared to be constant by the inclusion
    of a ``Final`` type hint.
-
-
 """
 
 
@@ -48,7 +44,7 @@ def make_class(on_prevent_change=True):
             ):
                 if on_prevent_change:
                     if callable(on_prevent_change):
-                        on_prevent_change(
+                        on_prevent_change(  # noqa
                             filename=self.__file__, key=key, value=value, kind="set"
                         )
                     return
@@ -58,7 +54,7 @@ def make_class(on_prevent_change=True):
             if key in CONSTANTS[self.__file__]:
                 if on_prevent_change:
                     if callable(on_prevent_change):
-                        on_prevent_change(
+                        on_prevent_change(  # noqa
                             filename=self.__file__, key=key, kind="delete"
                         )
                     return
@@ -119,7 +115,7 @@ class FinalDict(dict):
     def setdefault(self, key, default=None):
         """Insert key with a value of default if key is not in the dictionary.
 
-        Prevents changes if the key is identified as a constant.
+        It prevents changes if the key is identified as a constant.
         """
         if key in CONSTANTS[self.__file__]:
             if self.on_prevent_change:
@@ -134,7 +130,7 @@ class FinalDict(dict):
 
     def pop(self, key):
         """D.pop(key) -> value, remove specified key and return the corresponding value,
-        unless the key is identifed as a constant.
+        unless the key is identified as a constant.
 
         If key is not found, d is returned if given, otherwise KeyError is raised
         """
@@ -195,7 +191,7 @@ def transform_source(source, filename=None, **_kwargs):
     return source
 
 
-def exec_(code_object, filename=None, globals_=None, callback_params=None, **kwargs):
+def exec_(code_object, filename=None, module=None, callback_params=None, **kwargs):
     """Executes a code_object in a local instance of a ``FinalDict``.
 
     The argument ``globals_`` is assumed to be the original module's ``__dict__``.
@@ -211,9 +207,9 @@ def exec_(code_object, filename=None, globals_=None, callback_params=None, **kwa
     locals_ = FinalDict(
         filename, on_prevent_change=callback_params["on_prevent_change"]
     )
-    locals_.update(globals_)
+    locals_.update(module.__dict__)
     exec(code_object, locals_)
-    globals_.update(locals_)
+    module.__dict__.update(locals_)
 
 
 def on_change_print(filename=None, key=None, value=None, kind=None):
@@ -231,7 +227,7 @@ def on_change_print(filename=None, key=None, value=None, kind=None):
         raise NotImplementedError
 
 
-def add_hook(on_prevent_change=None, verbose_finder=False, **_kwargs):
+def add_hook(on_prevent_change=None, **_kwargs):
     """Creates and adds the import hook in sys.meta_path
 
     When an attempt is made to change the value of a constant, ``on_prevent_change``
@@ -254,6 +250,5 @@ def add_hook(on_prevent_change=None, verbose_finder=False, **_kwargs):
         callback_params=callback_params,
         console_dict=console_dict,
         hook_name=__name__,
-        verbose_finder=verbose_finder,
     )
     return hook
